	  %
	  % sl_plot ( x, y [, options ] )
	  %
	  % plot a curve (x and y arrays), using the ChIPS state object 
	  % to control the appearance (the optional options associative 
	  % array)
	  %
	  % The allowed keys for the options associative array are the
	  % same as the ChIPS state object (see ahelp slang-chips), ie:
	  %   curvestyle symbolstyle linestyle curvecolor symbolcolor 
	  %   linecolor symbolsize font undo savevars tmpdir tmpdata     
	  %
	  
	  % create the list of allowed options fron the ChIPS state object
	  % - only the keys are important here, the values are not
	  %
	  variable _chips_opts = Assoc_Type [Integer_Type];
	  _chips_opts["curvestyle"] = 0;
	  _chips_opts["symbolstyle"] = 0;
	  _chips_opts["linestyle"] = 0;
	  _chips_opts["curvecolor"] = 0;
	  _chips_opts["symbolcolor"] = 0;
	  _chips_opts["linecolor"] = 0;
          _chips_opts["symbolsize"] = 0;
	  _chips_opts["font"] = 0;
	  _chips_opts["undo"] = 0;
	  _chips_opts["savevars"] = 0;
	  _chips_opts["tmpdir"] = 0;
	  _chips_opts["tmpdata"] = 0;
	  
	  define sl_plot () {
	  
	    variable usage_str = "sl_plot( x, y [, options ] )\n"
	  	+ "where x and y are arrays and options is an " 
	        + "associative array\n";
	    variable useropts, origopts, x, y;
	  
	    % check usage - use the switch() structure instead of a set
	    % of "if/else if" commands.
	    %
	    switch ( _NARGS )
	      { case 3 : 
	          ( x, y, useropts ) = ();
	          % all args removed from stack, so do not need to clear it
	          % if there is an error
	          if ( typeof( useropts ) != Assoc_Type ) 
	            usage( usage_str ); }
	      { case 2 : 
	          useropts = NULL;
	          ( x, y ) = (); }
	      { % incorrect number of arguments
	        usage( usage_str ); }
	  
	    % if useropts is non-NULL, then update the ChIPS state object
	    % storing the original values in origopts
	    %
	    if ( useropts != NULL ) {
	      % we do not define a type for origopts as we have to be able to 
	      % store integers (eg curvestyle) and strings (eg tmpdir)
	      origopts = Assoc_Type [];
	  
	      % loop through the input options
	      variable key;
	      foreach ( assoc_get_keys( useropts ) ) {
	        key = ();
	  
	        % is this a valid key?
	        if ( assoc_key_exists( _chips_opts, key ) ) {
	  
	          % store original value, update ChIPS state object
	          origopts[key] = get_struct_field( chips, key );
	          set_struct_field( chips, key, useropts[key] );
	  
	        } else {
	          vmessage( "Ignoring unknown ChIPS option %s", key );
	        }
	  
	      } % foreach
	    } % if: useropts != NULL
	  
	    % plot the data - use the S-Lang curve() function since we
	    % do not need the full functionality of the ChIPS curve command
	    %
	    () = chips_eval("clear");
	    () = curve( x, y );
	  
	    % restore the original ChIPS state object (if we changed it)
	    %
	    if ( useropts != NULL ) {
	      foreach ( assoc_get_keys( origopts ) ) {
	        key = ();
	        set_struct_field( chips, key, origopts[key] );
	      } % foreach
	    } % if: useropts != NULL
	  
	    return;
	  
	  } % sl_plot()
