          %
          % sl_plot ( x, y [, ChIPS state object ] )
          %
          % plot a curve (x and y arrays), using the ChIPS state object 
          % to control the appearance (the optional options associative 
          % array)
          %
          % unlike example 11, the optional third argument is a copy
          % of the ChIPS state object, with its fields set to the desired
          % plot attributes
          %
          
          define sl_plot () {
          
            variable usage_str = "sl_plot( x, y [, ChIPS state object ] )\n"
                + "where x and y are arrays";
            variable useropts, origopts, x, y;
          
            % check usage - use the switch() structure instead of a set
            % of "if/else if" commands.
            %
            switch ( _NARGS )
              { case 3 : 
                  ( x, y, useropts ) = ();
                  % all args removed from stack, so do not need to clear it
                  % if there is an error
                  if ( typeof(useropts) != Struct_Type and 
                       typeof(useropts) != chips_State ) {
                    print( usage_str ); 
                    return;
                  }
              }
              { case 2 : 
                  useropts = NULL;
                  ( x, y ) = (); 
              }
              { % incorrect number of arguments, remove any arguments from
                % the stack
                % 
                if ( _NARGS != 0 ) _pop_n( _NARGS ); 
                print( usage_str ); 
                return;
              }
          
            % if useropts is non-NULL, then update the ChIPS state object
            % storing the original values in origopts
            %
            if ( useropts != NULL ) {
              origopts = @chips;
              set_state( "chips", useropts );
        
            } % if: useropts != NULL
          
            % plot the data - use the S-Lang curve() function since we
            % do not need the full functionality of the ChIPS curve command
            %
            () = chips_eval("clear");
            () = curve( x, y );
          
            % restore the original ChIPS state object (if we changed it)
            %
            if ( useropts != NULL ) set_state( "chips", origopts );
          
            return;
          
          } % sl_plot()
