	  % Usage:
	  %   ( mean, rms, median, min, max, total, ngood ) 
	  %     = calc_stats( array_var )
	  %
	  % Aim:
	  %  calculate simple stats for the supplied array
	  %  array_var can be of any dimensionality - all
	  %  elements are used in the calculation. If the
	  %  array is > 1D, then a 1D copy of the array is 
	  %  made, which means the routine can use a lot
	  %  of memory if sent a large array
	  %
	  %  The routine includes code to calculate the median of
	  %  the array, but it's a simple, and so slow, method.
	  %
	  define calc_stats() {
	    % Have we been called correctly?
	    if (_NARGS != 1) {
	      usage( "() = calc_stats(a)\nwhere a is an array of numbers" );
	    }
	    variable a = ();
	    if (typeof(a) != Array_Type) {
	      usage( "() = calc_stats(a)\nwhere a is an array of numbers" );
	    }  
	
	    % total number of elements in array (whatever the dimensionality)
	    variable npts = length(a);
	
	    % Find out the size of the array: reshape if not 1D
	    % (we are not interested in array dimensions or type)
	    variable n1;
	    ( , n1, ) = array_info( a );
	    if ( n1 > 1 ) {
	      a = _reshape( a, [npts] ); % make a copy
	    }
	
	    % calculate the stats
	    variable total, minval, maxval, value;
	   
	    total  = 0;
	    minval = a[0];
	    maxval = a[0];
	
	    % loop through array elements
	    foreach (a) {
	      value = ();
	      total += value;
	      if ( value < minval )      { minval = value; }
	      else if ( value > maxval ) { maxval = value; }
	    }
	
	    % ensure we have a floating-point calculation
	    variable mean = total * 1.0 / npts;
	
	    % calculate the RMS using the corrected two-pass algorithm
	    variable diff, sum, sumsq;
	    sum   = 0.0;
	    sumsq = 0.0;
	    foreach ( a ) {
	      % diff = current element - mean
	      diff   = () - mean;
	      sum   += diff;
	      sumsq += (diff*diff);
	    }
	
	    % again ensure we're doing this in floating point
	    variable rms = sqrt( (sumsq - sum*sum*1.0/npts) / (npts-1.0) );
	
	    % calculate the median using a rather simple/slow algorithm
	    % - for the median of an even-sized array we take the average of
	    %   the 'low' and 'high' values
	    variable index = array_sort( a );
	    variable midpt, median;
	    midpt = (npts-1) / 2;
	    if ( int(midpt) == midpt ) {
	      % npts is odd
	      median = a[index[midpt]];
	    } else {
	      % npts is even
	      median = 0.5 * ( a[index[midpt-0.5]] + a[index[midpt+0.5]] );
	    }

            variable stats = struct { mean, median, rms, minval, maxval, 
                  total, npts };
            set_struct_fields( stats, mean, median, rms, minval, maxval, 
                  total, npts );
            return stats;

	  } % calc_stats()
		
